# Lisez-moi !

Cette application permet de calculer le montant HT, la TVA et le montant TTC selon l'une des 3 bases :
-> montant HT
-> montant de la TVA
-> montant TTC
À cela on peut choisir le taux de TVA à appliquer